@@ -5,6 +5,6 @@ test_that("Metacommunity and BoundaryClump agree", {
 	test <- matrix(rbinom(100,1,0.5), ncol=10)
 	mc.test <- Metacommunity(test, sims=10, method='swap')
 	bc.test <- BoundaryClump(test)
-	expect_equal(as.numeric(mc.test$Boundary[1]), 
-    as.numeric(bc.test[1]))
+	expect_equal(mc.test$Boundary$stat[1], 
+    bc.test$stat[1])
 })
